@@ -21,14 +21,24 @@
  * IN THE SOFTWARE.
  */
 
-#ifndef __GJS_CONTEXT_H__
-#define __GJS_CONTEXT_H__
+#ifndef GJS_CONTEXT_H_
+#define GJS_CONTEXT_H_
 
-#if !defined (__GJS_GJS_H__) && !defined (GJS_COMPILATION)
-#error "Only <gjs/gjs.h> can be included directly."
+#if !defined(INSIDE_GJS_H) && !defined(GJS_COMPILATION)
+#    error "Only <gjs/gjs.h> can be included directly."
+#endif
+
+#include <stdbool.h>    /* IWYU pragma: keep */
+
+#ifndef _WIN32
+#    include <sys/signal.h> /* for siginfo_t */
 #endif
 
 #include <glib-object.h>
+#include <glib.h>
+
+#include <gjs/macros.h>
+#include <gjs/profiler.h>
 
 G_BEGIN_DECLS
 
@@ -42,39 +52,54 @@ typedef struct _GjsContextClass GjsContextClass;
 #define GJS_IS_CONTEXT_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), GJS_TYPE_CONTEXT))
 #define GJS_CONTEXT_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS ((obj), GJS_TYPE_CONTEXT, GjsContextClass))
 
-GType           gjs_context_get_type             (void) G_GNUC_CONST;
+GJS_EXPORT GJS_USE GType gjs_context_get_type(void) G_GNUC_CONST;
 
-const char *    gjs_context_scan_file_for_js_version (const char *file_path);
-const char *    gjs_context_scan_buffer_for_js_version (const char *buffer, gssize len);
+GJS_EXPORT GJS_USE GjsContext* gjs_context_new(void);
+GJS_EXPORT GJS_USE GjsContext* gjs_context_new_with_search_path(
+    char** search_path);
+GJS_EXPORT GJS_USE bool gjs_context_eval_file(GjsContext* js_context,
+                                              const char* filename,
+                                              int* exit_status_p,
+                                              GError** error);
+GJS_EXPORT GJS_USE bool gjs_context_eval(GjsContext* js_context,
+                                         const char* script, gssize script_len,
+                                         const char* filename,
+                                         int* exit_status_p, GError** error);
+GJS_EXPORT GJS_USE bool gjs_context_define_string_array(
+    GjsContext* js_context, const char* array_name, gssize array_length,
+    const char** array_values, GError** error);
 
-GjsContext*     gjs_context_new                  (void);
-GjsContext*     gjs_context_new_with_search_path (char         **search_path);
-gboolean        gjs_context_eval_file            (GjsContext  *js_context,
-                                                  const char    *filename,
-                                                  int           *exit_status_p,
-                                                  GError       **error);
-gboolean        gjs_context_eval                 (GjsContext  *js_context,
-                                                  const char    *script,
-                                                  gssize         script_len,
-                                                  const char    *filename,
-                                                  int           *exit_status_p,
-                                                  GError       **error);
-gboolean        gjs_context_define_string_array  (GjsContext  *js_context,
-                                                  const char    *array_name,
-                                                  gssize         array_length,
-                                                  const char   **array_values,
-                                                  GError       **error);
+GJS_EXPORT GJS_USE GList* gjs_context_get_all(void);
 
-GList*          gjs_context_get_all              (void);
+GJS_EXPORT GJS_USE GjsContext* gjs_context_get_current(void);
+GJS_EXPORT
+void            gjs_context_make_current         (GjsContext *js_context);
+
+GJS_EXPORT
 void*           gjs_context_get_native_context   (GjsContext *js_context);
 
-void            gjs_context_print_stack_to_buffer (GjsContext *js_context,
-                                                   GString    *buf);
-
+GJS_EXPORT
 void            gjs_context_print_stack_stderr    (GjsContext *js_context);
 
+GJS_EXPORT
+void            gjs_context_maybe_gc              (GjsContext  *context);
+
+GJS_EXPORT
+void            gjs_context_gc                    (GjsContext  *context);
+
+GJS_EXPORT GJS_USE GjsProfiler* gjs_context_get_profiler(GjsContext* self);
+
+GJS_EXPORT GJS_USE bool gjs_profiler_chain_signal(GjsContext* context,
+                                                  siginfo_t* info);
+
+GJS_EXPORT
 void            gjs_dumpstack                     (void);
 
+GJS_EXPORT GJS_USE const char* gjs_get_js_version(void);
+
+GJS_EXPORT
+void gjs_context_setup_debugger_console(GjsContext* gjs);
+
 G_END_DECLS
 
-#endif  /* __GJS_CONTEXT_H__ */
+#endif /* GJS_CONTEXT_H_ */
